<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general',
        'title'       => __('General','beant2d')
      ),
      array(
        'id'          => 'logo_settings',
        'title'       => __('Logo Settings','beant2d')
      ),
      array(
        'id'          => 'themecustomizer',
        'title'       => __('Theme Customizer','beant2d')
      ),
      array(
        'id'          => 'menusettings',
        'title'       => __('Top Bar Settings','beant2d')
      ),
      array(
        'id'          => 'menulayout',
        'title'       => __('Menu Buttons','beant2d')
      ),
      array(
        'id'          => 'menusettinsconf',
        'title'       => __('Menu Settings','beant2d')
      ),
     
      array(
        'id'          => 'maincontentsettings',
        'title'       => __('Content Settings','beant2d')
      ),
      array(
        'id'          => 'general_typography',
        'title'       => __('Typography','beant2d')
      ),
      array(
        'id'          => 'splashscreen',
        'title'       => __('iOS Splash Screens','beant2d')
      ),
      array(
        'id'          => 'iossettings',
        'title'       => __('iOS Add Home Bubble','beant2d')
      ),
      array(
        'id'          => 'iostouchicon',
        'title'       => __('iOS Touch Icons','beant2d')
      ),
      array(
        'id'          => 'autoupdatemobile',
        'title'       => __('Auto Update','beant2d')
      )
    ),
    'settings'        => array( 
	array(
        'id'          => 'mhelpbox_help14',
        'label'       => __('Info','beant2d'),
        'desc'        => __('You can find Envato Username and API key in to the Envato Control Panel > My Settings > API Key. <a href="http://www.webbudesign.com/envato/apikey.png" target="_blank">For more detail click here to see help photo.</a>','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'autoupdatemobile',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '' 
      ),
	  array(
        'id'          => 'general_brcm',
        'label'       => __('Breadcrumbs','beant2d'),
        'desc'        => __('This option will enable / disable Breadcrumbs feature.','beant2d'),
        'std'         => '0',
        'type'        => 'radio',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'general_shrm',
        'label'       => __('Share Menu','beant2d'),
        'desc'        => __('This option will enable / disable top share button & menu feature.','beant2d'),
        'std'         => '0',
        'type'        => 'radio',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'general_beanmblur',
        'label'       => __('Blur Effect on Menu','beant2d'),
        'desc'        => __('This option will enable / disable blur effect on menu open/close.','beant2d'),
        'std'         => '0',
        'type'        => 'radio',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'general_ioswebapp',
        'label'       => __('iOS Web App','beant2d'),
        'desc'        => __('This option will enable / disable iOS iWeb App feature.','beant2d'),
        'std'         => '1',
        'type'        => 'radio',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'general_loading',
        'label'       => __('Loading Animation','beant2d'),
        'desc'        => __('You can stop loading animation by disable this.','beant2d'),
        'std'         => '1',
        'type'        => 'radio',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'general_loadingcolor',
        'label'       => __('Loading Window BG Color','beant2d'),
        'desc'        => __('You can change loading animation background color. Default: Black','aurat2d'),
        'std'         => 'black',
        'type'        => 'radio',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'white',
            'label'       => __('White','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => 'black',
            'label'       => __('Black','beant2d'),
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'general_customcss',
        'label'       => __('Custom CSS Code','beant2d'),
        'desc'        => __('You can copy &amp; paste your custom css codes in this area. (Optional)','beant2d'),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'googleanalytics_code',
        'label'       => __('Google Analytics Code','beant2d'),
        'desc'        => __('Please copy &amp; paste your google analytic code with  ...  tags.','beant2d'),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'logosettings_topmargin',
        'label'       => __('Logo Top Margin','beant2d'),
        'desc'        => __('Top margin for logo.','beant2d'),
        'std'         => '10',
        'type'        => 'numeric-slider',
        'section'     => 'logo_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '0,100,1',
        'class'       => ''
      ),
      array(
        'id'          => 'logosettings_image',
        'label'       => __('Logo Image','beant2d'),
        'desc'        => __('You can upload your custom logo image and disable text logo. If leave empty text logo will be displayed. Also you can find a sample logo in sources folder.','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'logo_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'custom_menu_location',
        'label'       => __('Logo Location','beant2d'),
        'desc'        => __('If you move menu button to the left the logo will be on right.','beant2d'),
        'std'         => '1',
        'type'        => 'select',
        'section'     => 'logo_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Show Buttons on Left & Logo on Right','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Show Buttons on Right & Logo on Left','beant2d'),
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'mhelpbox_help12',
        'label'       => __('Info','beant2d'),
        'desc'        => __('If choose to use theme customizer, not need to use custom configurations. This customizer will change Header, Menu Layout, Menu Settings and Content Settings. You need to click "Accept Change" after select your theme.<br><br><strong>Warning :</strong> After "Apply Changes" your old settings will erase. Please backup your existing setting with Import/Export manager before change.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'themecustomizer',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'wmfthemecustomizer_apply',
        'label'       => __('Apply Theme Settings','beant2d'),
        'desc'        => '',
        'std'         => '0',
        'type'        => 'radio',
        'section'     => 'themecustomizer',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Accept Change','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Decline Change','beant2d'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'wmfthemecustomizer',
        'label'       => __('Select Theme','beant2d'),
        'desc'        => '',
        'std'         => '0',
        'type'        => 'radio-image',
        'section'     => 'themecustomizer',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Style 1','beant2d'),
            'src'         => 'assets/images/tcustomizer/s1.png'
          ),
          array(
            'value'       => '2',
            'label'       => __('Style 2','beant2d'),
            'src'         => 'assets/images/tcustomizer/s2.png'
          ),
		  array(
            'value'       => '3',
            'label'       => __('Style 3','beant2d'),
            'src'         => 'assets/images/tcustomizer/s3.png'
          ),
		  array(
            'value'       => '4',
            'label'       => __('Style 4','beant2d'),
            'src'         => 'assets/images/tcustomizer/s4.png'
          ),
		  array(
            'value'       => '5',
            'label'       => __('Style 5','beant2d'),
            'src'         => 'assets/images/tcustomizer/s5.png'
          ),
		  array(
            'value'       => '6',
            'label'       => __('Style 6','beant2d'),
            'src'         => 'assets/images/tcustomizer/s6.png'
          ),
		  array(
            'value'       => '7',
            'label'       => __('Style 7','beant2d'),
            'src'         => 'assets/images/tcustomizer/s7.png'
          )
        ),
      ),
      array(
        'id'          => 'mhelpbox_help1',
        'label'       => __('Info','beant2d'),
        'desc'        => __('Below settings will effect top bar area. You can leave blank for load default settings.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'menusettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_topheaderbackground',
        'label'       => __('Top Bar Background','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'menusettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_topheaderbackground2',
        'label'       => __('Top Bar Background Gradient Color','beant2d'),
        'desc'        => __('Please select second color for gradient, after select "Top Bar Background" &gt; Color. (Optional)','beant2d'),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'menusettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_topheaderheight',
        'label'       => __('Top Bar Height (px)','beant2d'),
        'desc'        => __('Change top bar height value. Default:40px;','beant2d'),
        'std'         => '40',
        'type'        => 'numeric-slider',
        'section'     => 'menusettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '40,586,1',
        'class'       => ''
      ),
	  
	 
	  
      array(
        'id'          => 'mhelpbox_help2',
        'label'       => __('Info','beant2d'),
        'desc'        => __('Below settings will effect header menu button icon, text and type. You can leave blank for load default settings.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'menulayout',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'menulayout_custommenuimg',
        'label'       => __('Custom Menu Button Image','beant2d'),
        'desc'        => __('You can upload your own menu button or leave this setting blank for default image. Check sources folder for sample.(Sources &gt; menubuttons)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'menulayout',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'menulayout_custommenuimgclose',
        'label'       => __('Custom Menu Close Button Image','beant2d'),
        'desc'        => __('You can upload your own menu close button or leave this setting blank for default image. Check sources folder for sample.(Sources &gt; menubuttons)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'menulayout',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'menulayout_custommenushareimg',
        'label'       => __('Custom Share Button Image','beant2d'),
        'desc'        => __('You can upload your own share button or leave this setting blank for default image. Check sources folder for sample.(Sources &gt; menubuttons)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'menulayout',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'menulayout_custommenushareimgclose',
        'label'       => __('Custom Share Close Button Image','beant2d'),
        'desc'        => __('You can upload your own share close button or leave this setting blank for default image. Check sources folder for sample.(Sources &gt; menubuttons)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'menulayout',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
	  
      array(
        'id'          => 'mhelpbox_help4',
        'label'       => __('Info','beant2d'),
        'desc'        => __('Below settings will effect menu button. You can leave blank for load default settings.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'menusettinsconf',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
      array(
        'id'          => 'menusettings_buttonbg',
        'label'       => __('Menu Button Background Color','beant2d'),
        'desc'        => __('Left &amp; Right Menu button background color. Please leave blank for default settings. Default: #31394a','beant2d'),
        'std'         => '#31394a',
        'type'        => 'colorpicker',
        'section'     => 'menusettinsconf',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'custom_menu_fonthover',
        'label'       => __('Menu Button Background Hover Color','beant2d'),
        'desc'        => __('This settings will effect the left &amp; right menu hover. Please leave blank for default settings. Default:#242731','beant2d'),
        'std'         => '#242731',
        'type'        => 'colorpicker',
        'section'     => 'menusettinsconf',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'custom_menu_font',
        'label'       => __('Menu Font Typography','beant2d'),
        'desc'        => __('This settings will effect the left &amp; right menu text. Please leave blank for default settings.','beant2d'),
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'menusettinsconf',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'menusettings_menuopacity',
        'label'       => __('Menu Bar Opacity','beant2d'),
        'desc'        => __('Change menu opacity value. Default:0.9px;','beant2d'),
        'std'         => '0.9',
        'type'        => 'numeric-slider',
        'section'     => 'menusettinsconf',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '0,1,0.1',
        'class'       => ''
      ),
	  array(
        'id'          => 'menusettings_menuwidth',
        'label'       => __('Menu Width','beant2d'),
        'desc'        => __('Change menu width size. Default:3.6em;','beant2d'),
        'std'         => '3.6',
        'type'        => 'numeric-slider',
        'section'     => 'menusettinsconf',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '0,10,0.1',
        'class'       => ''
      ),
      array(
        'id'          => 'mhelpbox_help7',
        'label'       => __('Info','beant2d'),
        'desc'        => __('Below settings will effect content area. You can leave blank for load default settings.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_contentbackground',
        'label'       => __('Content Background','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_typography',
        'label'       => __('Content Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'tcustomizer_contentelementcolor1',
        'label'       => __('Content Elements Color 1','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'tcustomizer_contentelementcolor2',
        'label'       => __('Content Elements Color 2','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'tcustomizer_linktexttypo',
        'label'       => __('Link Text Color','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
	  array(
        'id'          => 'tcustomizer_linktexthovertypo',
        'label'       => __('Link Text Hover Color','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'blogbgcolor',
        'label'       => __('Blog Box Background Color','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'maincontentsettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'mhelpbox_help8',
        'label'       => __('Info','beant2d'),
        'desc'        => __('Below settings will effect typography of site. Leave all settings blank for load default typography.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_subst',
        'label'       => __('Sub String For Google Font','beant2d'),
        'desc'        => __('Sub string for Google Font.(Optional) <br>Ex:subset=latin,cyrillic-ext,greek-ext,vietnamese,greek,cyrillic,latin-ext','beant2d'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  
      array(
        'id'          => 'tcustomizer_typographyh1',
        'label'       => __('H1 Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_typographyh2',
        'label'       => __('H2 Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_typographyh3',
        'label'       => __('H3 Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_typographyh4',
        'label'       => __('H4 Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_typographyh5',
        'label'       => __('H5 Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'tcustomizer_typographyh6',
        'label'       => __('H6 Typography','beant2d'),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'general_typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'mhelpbox_help9',
        'label'       => __('Info','beant2d'),
        'desc'        => __('This feature only work in iOS devices. You will see different sized images below this instruction. These images are designed for device position &amp; type. Please upload all images. You can find sample images in Downloaded content &gt; Sources &gt; splash-screens folder.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_iphone3',
        'label'       => __('Splash Screen iPhone 3','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-320x460.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_iphone4',
        'label'       => __('Splash Screen iPhone4','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-640x920.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_iphone5',
        'label'       => __('Splash Screen iPhone 5','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-640x1096.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_porttablet',
        'label'       => __('Splash Screen Portrait Tablets','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-768x1004.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_landtablet',
        'label'       => __('Splash Screen Landscape Tablets','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-748x1024.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_porttabletret',
        'label'       => __('Splash Screen Portrait Retina Tablets','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-1536x2008.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'splashscreen_landtabletret',
        'label'       => __('Splash Screen Landscape Retina Tablets','beant2d'),
        'desc'        => __('You can upload your own splash screen image. Check sources folder for sample.(Sources &gt; splash-screens &gt; apple-touch-startup-image-1496x2048.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'splashscreen',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'mhelpbox_help10',
        'label'       => __('Info','beant2d'),
        'desc'        => __('This feature only work on iOS devices &amp; only work in Front Page. You need to select your static front page from Settings &gt; Reading page.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'iossettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'iossettings_add2home',
        'label'       => __('IOS Add Home Bubble','beant2d'),
        'desc'        => __('<br>Show/Hide Add to Home Bubble on IOS devices.(Default: Show)','beant2d'),
        'std'         => '1',
        'type'        => 'radio',
        'section'     => 'iossettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => __('Show','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => '0',
            'label'       => __('Hide','beant2d'),
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'iossettings_startdelay',
        'label'       => __('Start Delay','beant2d'),
        'desc'        => __('Start delay for message. (ms) 2000 for 2 sec.','beant2d'),
        'std'         => '2000',
        'type'        => 'numeric-slider',
        'section'     => 'iossettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '0,10000,1000',
        'class'       => ''
      ),
      array(
        'id'          => 'iossettings_lifespan',
        'label'       => __('Lifespan','beant2d'),
        'desc'        => __('Time before it is automatically destroyed. (ms) 5000 for 5 sec.','beant2d'),
        'std'         => '5000',
        'type'        => 'numeric-slider',
        'section'     => 'iossettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '0,30000,1000',
        'class'       => ''
      ),
      array(
        'id'          => 'iossettings_returningvisitor',
        'label'       => __('Returning Visitor','beant2d'),
        'desc'        => __('Show the message only to returning visitors. (ie: don\'t show it the first time)','beant2d'),
        'std'         => 'false',
        'type'        => 'radio',
        'section'     => 'iossettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'true',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => 'false',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'mhelpbox_help11',
        'label'       => __('Info','beant2d'),
        'desc'        => __('Touch icons will help to iOS users while adding your site to the home screen. The sizes are different because retina &amp; non-retina devices using different size icons. For find sample icons only check downloaded content &gt; sources &gt; touch-icons folder. You can change these images &amp; re upload here easily.','beant2d'),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'iostouchicon',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'iossettings_touchicon',
        'label'       => __('Touch Icon','beant2d'),
        'desc'        => __('This option will show an icon in to the add home balloon. If you enable touch icon you need to upload touch icons from touch icon section on the left menu.','beant2d'),
        'std'         => 'true',
        'type'        => 'radio',
        'section'     => 'iossettings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'true',
            'label'       => __('Enable','beant2d'),
            'src'         => ''
          ),
          array(
            'value'       => 'false',
            'label'       => __('Disable','beant2d'),
            'src'         => ''
          )
        ),
        
      ),
      array(
        'id'          => 'iostouchicon_1',
        'label'       => __('Touch Icon 57x57','beant2d'),
        'desc'        => __('You need to upload 57x57 px touch icon here. Check sources folder for sample.(touch-icons &gt; apple-touch-icon-57x57.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'iostouchicon',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'iostouchicon_2',
        'label'       => __('Touch Icon 72x72','beant2d'),
        'desc'        => __('You need to upload 72x72 px touch icon here. Check sources folder for sample.(touch-icons &gt; apple-touch-icon-72x72.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'iostouchicon',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'iostouchicon_3',
        'label'       => __('Touch Icon 114x114','beant2d'),
        'desc'        => __('You need to upload 114x114 px touch icon here. Check sources folder for sample.(touch-icons &gt; apple-touch-icon-114x114.png)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'iostouchicon',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'iostouchicon_4',
        'label'       => __('Touch Icon 144x144','beant2d'),
        'desc'        => __('Please select a color for header bar separator border. (Default: #000000)','beant2d'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'iostouchicon',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'autoupdate_username',
        'label'       => __('Envato Username','beant2d'),
        'desc'        => __('Please enter Themeforest Username','beant2d'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'autoupdatemobile',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'autoupdate_apikey2',
        'label'       => __('Envato API Key','beant2d'),
        'desc'        => __('Please enter Themeforest API Key','beant2d'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'autoupdatemobile',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}